@@ -2,6 +2,7 @@ from __future__ import annotations
 
 import asyncio as aio
 import logging as __logging
+from loguru import logger
 import typing as ty
 
 import aiohttp
@@ -77,14 +78,18 @@ class FluxClient(discord.Client):
    def register_command_listener(self):
       @self.router.listen_for(":message", decompose=True)
       async def _(message: discord.Message):
+         print("message reciveed")
          if not message.content or message.author is self.user:
             return
          ctx = MessageContext(bot=self, message=message)
 
          prefix = self.CONFIG.of(ctx)["prefix"]
+         print(prefix)
 
          if not message.content.startswith(prefix):
             return
-
+         if message.content.endswith("router"):
+            print(self.router.host)
          cmd = message.content.split(" ", 1)[0][len(prefix):]
-         await self.router.submit(event=aur.Event(f"flux:command:{cmd}"))
+         logger.info(f"Command recognized! flux:command:{cmd}")
+         await self.router.submit(event=aur.Event(f"flux:command:{cmd}", ctx=ctx))
